==> haskell-tasty-hedgehog-1.4.0.2-145-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-hedgehog.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-hedgehog
version:              1.4.0.2
visibility:           public
id:                   tasty-hedgehog-1.4.0.2-E5D0chzpkiy6md58rwwywA
key:                  tasty-hedgehog-1.4.0.2-E5D0chzpkiy6md58rwwywA
license:              BSD-3-Clause
copyright:
    Copyright (c) 2017, Commonwealth Scientific and Industrial Research Organisation (CSIRO) ABN 41 687 119 230.

maintainer:           dave.laing.80@gmail.com
author:               Dave Laing
homepage:             https://github.com/qfpl/tasty-hedgehog
synopsis:             Integration for tasty and hedgehog.
description:
    Integrates the <https://hackage.haskell.org/package/hedgehog hedgehog testing library> with the <https://hackage.haskell.org/package/tasty tasty testing framework>.

category:             Testing
abi:                  85738fdd59f2b38c3645e26ce4ad079f
exposed:              True
exposed-modules:      Test.Tasty.Hedgehog
import-dirs:          /usr/lib/ghc-9.4.8/site-local/tasty-hedgehog-1.4.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tasty-hedgehog-1.4.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tasty-hedgehog-1.4.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-hedgehog
hs-libraries:         HStasty-hedgehog-1.4.0.2-E5D0chzpkiy6md58rwwywA
depends:
    base-4.17.2.1 hedgehog-1.5-AFCopKV6AHY8Rixa0bLxvw
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C
    tasty-1.5-46UIB2PKK0iBCLLnvWYy2M

haddock-interfaces:
    /usr/share/doc/haskell-tasty-hedgehog/html/tasty-hedgehog.haddock

haddock-html:         /usr/share/doc/haskell-tasty-hedgehog/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-hedgehog-1.4.0.2-148-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-hedgehog.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-hedgehog
version:              1.4.0.2
visibility:           public
id:                   tasty-hedgehog-1.4.0.2-L5IZxrJgNbo9RT8s5lf8QT
key:                  tasty-hedgehog-1.4.0.2-L5IZxrJgNbo9RT8s5lf8QT
license:              BSD-3-Clause
copyright:
    Copyright (c) 2017, Commonwealth Scientific and Industrial Research Organisation (CSIRO) ABN 41 687 119 230.

maintainer:           dave.laing.80@gmail.com
author:               Dave Laing
homepage:             https://github.com/qfpl/tasty-hedgehog
synopsis:             Integration for tasty and hedgehog.
description:
    Integrates the <https://hackage.haskell.org/package/hedgehog hedgehog testing library> with the <https://hackage.haskell.org/package/tasty tasty testing framework>.

category:             Testing
abi:                  994d15a3d9b8e4d030b664563e41d882
exposed:              True
exposed-modules:      Test.Tasty.Hedgehog
import-dirs:          /usr/lib/ghc-9.4.8/site-local/tasty-hedgehog-1.4.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tasty-hedgehog-1.4.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tasty-hedgehog-1.4.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-hedgehog
hs-libraries:         HStasty-hedgehog-1.4.0.2-L5IZxrJgNbo9RT8s5lf8QT
depends:
    base-4.17.2.1 hedgehog-1.5-KDK23ochiFNo3CfVc9hFm
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C
    tasty-1.5-1INChxXs8WCKs4HPYbGvIu

haddock-interfaces:
    /usr/share/doc/haskell-tasty-hedgehog/html/tasty-hedgehog.haddock

haddock-html:         /usr/share/doc/haskell-tasty-hedgehog/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
